@@ -4,7 +4,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      $Id: app.h,v 1.19 2004/03/02 20:13:19 mbarbon Exp $
+// RCS-ID:      $Id: app.h,v 1.22 2004/08/04 20:13:55 mbarbon Exp $
 // Copyright:   (c) 2000-2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -24,7 +24,23 @@ public:
 
     bool OnInit();
     int MainLoop();
-    void CleanUp() { DeletePendingObjects(); wxApp::CleanUp(); }
+    void CleanUp() { DeletePendingObjects( this ); wxApp::CleanUp(); }
+
+#if defined( __WXMSW__ ) && !WXPERL_W_VERSION_GE( 2, 5, 0 )
+    static void SetKeepGoing(wxPliApp* app, bool value)
+    {
+        app->m_keepGoing = value;
+    }
+#endif
+
+    void DeletePendingObjects() {
+        wxApp::DeletePendingObjects();
+    }
+
+    static void DeletePendingObjects(wxApp* app)
+    {
+        ((wxPliApp*) app)->DeletePendingObjects();
+    }
 
     DEC_V_CBACK_INT__VOID( OnExit );
     DEC_V_CBACK_BOOL__BOOL( Yield );
@@ -33,7 +49,7 @@ public:
 inline wxPliApp::wxPliApp( const char* package )
     :m_callback( "Wx::App" ) 
 {
-    m_callback.SetSelf( wxPli_make_object( this, package ), TRUE );
+    m_callback.SetSelf( wxPli_make_object( this, package ), true );
 }
 
 wxPliApp::~wxPliApp()
@@ -59,7 +75,7 @@ inline bool wxPliApp::OnInit()
 {
     wxApp::OnInit();
 
-    return FALSE;
+    return false;
 }
 
 inline int wxPliApp::MainLoop() {
