@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dialog.h
+// Name:        cpp/dialog.h
 // Purpose:     c++ wrapper for wxDialog
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      
+// RCS-ID:      $Id: dialog.h,v 1.7 2004/08/04 20:13:55 mbarbon Exp $
 // Copyright:   (c) 2000-2001 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -15,8 +15,8 @@ class wxPliDialog:public wxDialog
     WXPLI_DECLARE_DYNAMIC_CLASS( wxPliDialog );
     WXPLI_DECLARE_V_CBACK();
 public:
-    WXPLI_DEFAULT_CONSTRUCTOR( wxPliDialog, "Wx::Dialog", TRUE );
-    WXPLI_CONSTRUCTOR_7( wxPliDialog, "Wx::Dialog", TRUE,
+    WXPLI_DEFAULT_CONSTRUCTOR( wxPliDialog, "Wx::Dialog", true );
+    WXPLI_CONSTRUCTOR_7( wxPliDialog, "Wx::Dialog", true,
                          wxWindow*, wxWindowID, const wxString&,
                          const wxPoint&, const wxSize&,
                          long, const wxString& );
