@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        frame.h
+// Name:        cpp/frame.h
 // Purpose:     c++ wrapper for wxFrame
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     29/10/2000
-// RCS-ID:      
+// RCS-ID:      $Id: frame.h,v 1.12 2004/08/04 20:13:55 mbarbon Exp $
 // Copyright:   (c) 2000-2002 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -15,8 +15,8 @@ class wxPliFrame:public wxFrame
     WXPLI_DECLARE_DYNAMIC_CLASS( wxPliFrame );
     WXPLI_DECLARE_V_CBACK();
 public:
-    WXPLI_DEFAULT_CONSTRUCTOR( wxPliFrame, "Wx::Frame", TRUE );
-    WXPLI_CONSTRUCTOR_7( wxPliFrame, "Wx::Frame", TRUE,
+    WXPLI_DEFAULT_CONSTRUCTOR( wxPliFrame, "Wx::Frame", true );
+    WXPLI_CONSTRUCTOR_7( wxPliFrame, "Wx::Frame", true,
                          wxWindow*, wxWindowID, const wxString&,
                          const wxPoint&, const wxSize&, long, 
                          const wxString& );
