@@ -3,8 +3,8 @@
 // Purpose:     c++ wrapper for wxLog and wxLogPassThrough
 // Author:      Mattia Barbon
 // Modified by:
-// Created:     22/ 9/2002
-// RCS-ID:      $Id: log.h,v 1.2 2003/05/05 20:38:41 mbarbon Exp $
+// Created:     22/09/2002
+// RCS-ID:      $Id: log.h,v 1.3 2004/08/04 20:13:55 mbarbon Exp $
 // Copyright:   (c) 2002-2003 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -17,7 +17,7 @@ class wxPlLog : public wxLog
 //    WXPLI_DECLARE_DYNAMIC_CLASS( wxPlLog );
     WXPLI_DECLARE_V_CBACK();
 public:
-    WXPLI_DEFAULT_CONSTRUCTOR_NC( wxPlLog, "Wx::PlLog", TRUE );
+    WXPLI_DEFAULT_CONSTRUCTOR_NC( wxPlLog, "Wx::PlLog", true );
 
     DEC_V_CBACK_VOID__CWXCHARP_TIMET( DoLogString );
     DEC_V_CBACK_VOID__WXLOGLEVEL_CWXCHARP_TIMET( DoLog );
@@ -32,7 +32,7 @@ class wxPlLogPassThrough : public wxLogPassThrough
     WXPLI_DECLARE_V_CBACK();
 public:
     WXPLI_DEFAULT_CONSTRUCTOR_NC( wxPlLogPassThrough,
-                                  "Wx::PlLogPassThrough", TRUE );
+                                  "Wx::PlLogPassThrough", true );
 
     DEC_V_CBACK_VOID__CWXCHARP_TIMET( DoLogString );
     DEC_V_CBACK_VOID__WXLOGLEVEL_CWXCHARP_TIMET( DoLog );
