@@ -5,7 +5,7 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     30/03/2001
-// RCS-ID:      $Id: streams.h,v 1.4 2004/02/28 22:59:06 mbarbon Exp $
+// RCS-ID:      $Id: streams.h,v 1.5 2004/10/05 20:13:36 mbarbon Exp $
 // Copyright:   (c) 2001-2002, 2004 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -33,8 +33,13 @@ protected:
     size_t GetSize() const { return ~(size_t)0; }
     size_t OnSysRead( void* buffer, size_t bufsize );
 
+#if WXPERL_W_VERSION_GE( 2, 5, 2 )
+    wxFileOffset OnSysSeek(wxFileOffset seek, wxSeekMode mode);
+    wxFileOffset OnSysTell() const;
+#else
     off_t OnSysSeek(off_t seek, wxSeekMode mode);
     off_t OnSysTell() const;
+#endif
 protected:
     SV* m_fh;
 };
@@ -51,8 +56,13 @@ public:
 protected:
     size_t OnSysWrite( const void* buffer, size_t size );
 
+#if WXPERL_W_VERSION_GE( 2, 5, 2 )
+    wxFileOffset OnSysSeek(wxFileOffset seek, wxSeekMode mode);
+    wxFileOffset OnSysTell() const;
+#else
     off_t OnSysSeek(off_t seek, wxSeekMode mode);
     off_t OnSysTell() const;
+#endif
 protected:
     SV* m_fh;
 };
