@@ -1,10 +1,10 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        timer.h
+// Name:        cpp/timer.h
 // Purpose:     C++ wrapper for wxTimer
 // Author:      Mattia Barbon
 // Modified by:
-// Created:     14/ 2/2001
-// RCS-ID:      
+// Created:     14/02/2001
+// RCS-ID:      $Id: timer.h,v 1.6 2004/08/04 20:13:55 mbarbon Exp $
 // Copyright:   (c) 2001-2002 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -24,7 +24,7 @@ public:
 inline wxPliTimer::wxPliTimer( const char* package )
     :m_callback( "Wx::Timer" )
 {
-    m_callback.SetSelf( wxPli_make_object( this, package ), TRUE );
+    m_callback.SetSelf( wxPli_make_object( this, package ), true );
 }
 
 inline wxPliTimer::wxPliTimer( const char* package, wxEvtHandler* owner,
@@ -32,7 +32,7 @@ inline wxPliTimer::wxPliTimer( const char* package, wxEvtHandler* owner,
     :wxTimer( owner, id ),
      m_callback( "Wx::Timer" )
 {
-    m_callback.SetSelf( wxPli_make_object( this, package ), TRUE );
+    m_callback.SetSelf( wxPli_make_object( this, package ), true );
 }
 
 DEF_V_CBACK_VOID__VOID( wxPliTimer, wxTimer, Notify );
